@@ -3,15 +3,17 @@
 ##' @title log-likelihood for mot model
 ##'
 ##' @param param parameter vector: (beta_0, beta_1, ... , beta_m, sigma).
-##' @param x design matrix of the model.
+##' @param xx design matrix of the model.
 ##' @param y observation vector.
 ##' @param tau threshold vector from tau_1 to tau_K.
 ##'
 ##' @return log-likelihood, vector with all observations.
+##' @export 
 ##' @seealso \link[lmmot]{lmmot} 
 ##' @author Marvin Wright
 
-motLogLik <- function(param,x,y,tau) {
+motLogLik <- function(param,xx,y,tau) {
+  x <- xx
 
   #sigma <- exp(param[length(param)])
 	sigma <- param[length(param)]
